@@ -1,13 +1,5 @@
 /*
- * children.c - linked list for keeping node results
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 08-03-2016
- *
+ * children.c - linked list for keeping node results.
  */
 #include <stdlib.h>
 #include <cleri/children.h>
@@ -17,8 +9,7 @@
  */
 cleri_children_t * cleri__children_new(void)
 {
-    cleri_children_t * children =
-            (cleri_children_t *) malloc(sizeof(cleri_children_t));
+    cleri_children_t * children = cleri__malloc(cleri_children_t);
     if (children != NULL)
     {
         children->node = NULL;
@@ -45,7 +36,7 @@ int cleri__children_add(cleri_children_t * children, cleri_node_t * node)
         children = children->next;
     }
 
-    children->next = (cleri_children_t *) malloc(sizeof(cleri_children_t));
+    children->next = cleri__malloc(cleri_children_t);
     if (children->next == NULL)
     {
         return -1;
