@@ -1,14 +1,6 @@
 /*
  * node.c - node is created while parsing a string. a node old the result
  *          for one element.
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 08-03-2016
- *
  */
 #include <cleri/node.h>
 #include <stdlib.h>
@@ -27,8 +19,7 @@ cleri_node_t * CLERI_EMPTY_NODE = &CLERI__EMPTY_NODE;
  */
 cleri_node_t * cleri__node_new(cleri_t * cl_obj, const char * str, size_t len)
 {
-    cleri_node_t * node;
-    node = (cleri_node_t *) malloc(sizeof(cleri_node_t));
+    cleri_node_t * node = cleri__malloc(cleri_node_t);
 
     if (node != NULL)
     {
